Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(177)

Unified Diff: Source/WebKit/chromium/src/WorkerStorageQuotaCallbacksBridge.h

Issue 17648006: Rename WorkerContext to WorkerGlobalScope (Closed) Base URL: svn://svn.chromium.org/blink/trunk
Patch Set: Rebase on master Created 7 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: Source/WebKit/chromium/src/WorkerStorageQuotaCallbacksBridge.h
diff --git a/Source/WebKit/chromium/src/WorkerStorageQuotaCallbacksBridge.h b/Source/WebKit/chromium/src/WorkerStorageQuotaCallbacksBridge.h
index 1c4b62ee5630711ab86745d45c96e9ea6dc8db52..8503c2952b179fead24f7b49b3d33ef31ba62cd2 100644
--- a/Source/WebKit/chromium/src/WorkerStorageQuotaCallbacksBridge.h
+++ b/Source/WebKit/chromium/src/WorkerStorageQuotaCallbacksBridge.h
@@ -72,9 +72,9 @@ public:
void stop();
- static PassRefPtr<WorkerStorageQuotaCallbacksBridge> create(WebCore::WorkerLoaderProxy* workerLoaderProxy, WebCore::ScriptExecutionContext* workerContext, WebStorageQuotaCallbacksImpl* callbacks)
+ static PassRefPtr<WorkerStorageQuotaCallbacksBridge> create(WebCore::WorkerLoaderProxy* workerLoaderProxy, WebCore::ScriptExecutionContext* workerGlobalScope, WebStorageQuotaCallbacksImpl* callbacks)
{
- return adoptRef(new WorkerStorageQuotaCallbacksBridge(workerLoaderProxy, workerContext, callbacks));
+ return adoptRef(new WorkerStorageQuotaCallbacksBridge(workerLoaderProxy, workerGlobalScope, callbacks));
}
// Entry method to post QueryUsageAndQuota task to main thread.
@@ -106,10 +106,10 @@ private:
Mutex m_loaderProxyMutex;
WebCore::WorkerLoaderProxy* m_workerLoaderProxy;
- WebCore::ScriptExecutionContext* m_workerContext;
+ WebCore::ScriptExecutionContext* m_workerGlobalScope;
- // Must be deleted on the WorkerContext thread.
- WorkerStorageQuotaContextObserver* m_workerContextObserver;
+ // Must be deleted on the WorkerGlobalScope thread.
+ WorkerStorageQuotaContextObserver* m_workerGlobalScopeObserver;
// This is self-destructed and must be fired on the worker thread.
WebStorageQuotaCallbacksImpl* m_callbacksOnWorkerThread;

Powered by Google App Engine
This is Rietveld 408576698